@@ -1,6 +1,10 @@
 #ifndef ELEKTRA_CONTEXTUAL_HPP
 #define ELEKTRA_CONTEXTUAL_HPP
 
+#ifdef HAVE_KDBCONFIG_H
+#include <kdbconfig.h>
+#endif
+
 #include <set>
 #include <map>
 #include <vector>
@@ -13,9 +17,14 @@
 #include <functional>
 #include <unordered_map>
 
+#include <kdbproposal.h>
 #include <keyset.hpp>
 
-#define ELEKTRA_INLINE __attribute__((noinline))
+#ifdef __GNUC__
+#define ELEKTRA_NOINLINE __attribute__((noinline))
+#else
+#define ELEKTRA_NOINLINE
+#endif
 
 namespace kdb
 {
@@ -464,43 +473,170 @@ private:
 };
 
 
+// Default Policies for ContextualValue
+// + mechanism for named policy switching
 
-// standard types
-
+/**
+ * @brief simply lookup without spec
+ */
 template<typename T>
-class ContextualValue : public Observer
+class DefaultGetPolicy
 {
 public:
 	typedef T type;
+	static type get(KeySet &ks, Key const& spec)
+	{
+		Key found = ks.lookup(spec.getName(), 0);
+		type val = type{};
+		if (found)
+		{
+			val = found.get<type>();
+#if DEBUG && VERBOSE
+		std::cout << "got name: " << m_spec.getName() << " to " << m_cache << std::endl;
+#endif
+		}
+		else
+		{
+			val = spec.getMeta<type>("default");
+#if DEBUG && VERBOSE
+		std::cout << "got default name: " << m_spec.getName() << " to " << m_cache << std::endl;
+#endif
+		}
+
+		return val;
+	}
+};
+
+/**
+ * @brief Implements update when key is not found.
+ *
+ * The new value always can be written out
+ */
+class DefaultSetPolicy
+{
+public:
+	typedef void type;
+	static Key set(KeySet &ks, Key const& spec)
+	{
+		kdb::Key found = ks.lookup(spec.getName(), 0);
+
+		if(!found)
+		{
+			kdb::Key k("user/"+spec.getName(), KEY_END);
+			ks.append(k);
+			found = k;
+		}
+
+		return found;
+	}
+};
+
+/**
+ * This technique with the PolicySelector and Discriminator is taken
+ * from the book  "C++ Templates - The Complete Guide"
+ * by David Vandevoorde and Nicolai M. Josuttis, Addison-Wesley, 2002 
+ *
+ * The technique allows users of the class Context to use any number
+ * and order of policies as desired.
+ */
+template <typename Base, int D>
+class Discriminator : public Base
+{
+};
+
+template < typename Setter1,
+	   typename Setter2
+>
+class PolicySelector : public Discriminator<Setter1,1>,
+			public Discriminator<Setter2,2>
+{
+};
+
+template<typename T>
+class DefaultPolicies
+{
+public:
+	typedef DefaultGetPolicy<T> GetPolicy;
+	typedef DefaultSetPolicy SetPolicy;
+};
+
+template<typename T>
+class DefaultPolicyArgs : virtual public DefaultPolicies<T>
+{
+};
+
+
+// class templates to override the default policy values
+
+/// Needed to set the event manager policy
+///
+/// @tparam Policy
+template <typename Policy>
+class GetPolicyIs : virtual public DefaultPolicies<typename Policy::type>
+{
+public:
+	typedef Policy GetPolicy;  // overriding typedef
+};
+
+
+/// Needed to set the supervision policy
+///
+/// @tparam Policy
+template <typename Policy>
+class SetPolicyIs : virtual public DefaultPolicies<typename Policy::type>
+{
+public:
+	typedef Policy SetPolicy;  // overriding typedef
+};
+
+// standard types
+
+template<typename T,
+	typename PolicySetter1 = DefaultPolicyArgs<T>,
+	typename PolicySetter2 = DefaultPolicyArgs<T>>
+class ContextualValue :
+	public Observer
+{
+public:
+	typedef T type;
+	typedef PolicySelector<
+		PolicySetter1,
+		PolicySetter2
+		>
+		Policies;
 
 	// not to be constructed yourself
-	ContextualValue<T>(KeySet & ks, Context & context_, kdb::Key meta) :
+	ContextualValue<T, PolicySetter1, PolicySetter2>
+		(KeySet & ks, Context & context_, kdb::Key spec) :
 		m_cache(),
 		m_ks(ks),
 		m_context(context_),
-		m_meta(meta),
-		m_evaluated_name(m_context.evaluate(m_meta.getString()))
+		m_spec(spec)
 	{
-		assert(m_meta.getString()[0] == '/');
+		assert(m_spec.getName()[0] == '/');
+		m_spec.setMeta("name", m_spec.getName());
+		ckdb::elektraKeySetName(*m_spec,
+				m_context.evaluate(m_spec.getName()).c_str(),
+				ckdb::KDB_O_CASCADING_NAME);
 		syncCache();  // read what we have in our context
-		m_context.attachByName(m_meta.getString(), *this);
+		m_context.attachByName(m_spec.getMeta<std::string>("name"), *this);
 	}
 
-	ContextualValue<T>(ContextualValue<T> const & other, KeySet & ks) :
+	ContextualValue<T, PolicySetter1, PolicySetter2>
+		(ContextualValue<T> const & other, KeySet & ks) :
 		m_cache(other.m_cache),
 		m_ks(ks),
 		m_context(other.m_context),
-		m_meta(other.m_meta),
-		m_evaluated_name(other.m_evaluated_name)
+		m_spec(other.m_spec)
 	{
-		assert(m_meta.getString()[0] == '/');
+		assert(m_spec.getName()[0] == '/');
 		// cache already in sync
 		// attach copy, too:
-		m_context.attachByName(m_meta.getString(), *this);
+		m_context.attachByName(m_spec.getMeta<std::string>("name"), *this);
 	}
 
 public:
-	ContextualValue<T> const & operator= (type n)
+	ContextualValue<T, PolicySetter1, PolicySetter2> const & operator= (type n)
 	{
 		m_cache = n;
 
@@ -522,19 +658,14 @@ public:
 			return m_cache;
 	}
 
-	bool operator == (ContextualValue<T> const & other) const
+	bool operator == (ContextualValue<T, PolicySetter1, PolicySetter2> const & other) const
 	{
 		return m_cache == other.m_cache ;
 	}
 
 	type getDefault() const
 	{
-		return m_meta.getMeta<type>("default");
-	}
-
-	bool isEmpty() const
-	{
-		return !m_ks.lookup(m_meta.getString(), 0);
+		return m_spec.getMeta<type>("default");
 	}
 
 	/// We allow manipulation of context for const
@@ -545,50 +676,25 @@ public:
 	}
 
 	/// Do not inline so that we can use it for debugging
-	
-	ELEKTRA_INLINE std::string const & getEvaluatedName() const
+	ELEKTRA_NOINLINE Key const& getSpec() const
 	{
-		return m_evaluated_name;
+		return m_spec;
 	}
 
 	// keyset to cache
 	void syncCache() const
 	{
-		kdb::Key found = m_ks.lookup(m_evaluated_name, 0);
-		if (found)
-		{
-			m_cache = found.get<type>();
-		}
-		else
-		{
-			m_cache = getDefault();
-		}
-
-		/*
-		m_context_changed = false;
-		m_atomic_context_changed = false;
-		m_volatile_context_changed = false;
-		*/
-#if DEBUG && VERBOSE
-		std::cout << "got name: " << m_evaluated_name << " to " << m_cache << std::endl;
-#endif
+		m_cache = Policies::GetPolicy::get(m_ks, m_spec);
 	}
 
 	// cache to keyset
 	void syncKeySet() const
 	{
 #if DEBUG && VERBOSE
-		std::cout << "set name: " << m_evaluated_name << " to " << m_cache << std::endl;
+		std::cout << "set name: " << m_spec.getName() << " to " << m_cache << std::endl;
 #endif
-		kdb::Key found = m_ks.lookup(m_evaluated_name, 0);
-
-		if(!found)
-		{
-			kdb::Key k("user/"+m_evaluated_name, KEY_END);
-			k.set<type>(m_cache);
-			m_ks.append(k);
-		}
-		else
+		kdb::Key found = Policies::SetPolicy::set(m_ks, m_spec);
+		if (found)
 		{
 			found.set<type>(m_cache);
 		}
@@ -598,14 +704,16 @@ public:
 private:
 	virtual void update() const
 	{
-		std::string evaluated_name = m_context.evaluate(m_meta.getString());
+		std::string evaluated_name = m_context.evaluate(m_spec.getMeta<std::string>("name"));
 #if DEBUG && VERBOSE
-		std::cout << "update " << evaluated_name << " from " << m_evaluated_name << std::endl;
+		std::cout << "update " << evaluated_name << " from " << m_spec.getName() << std::endl;
 #endif
-		if (evaluated_name != m_evaluated_name)
+		if (evaluated_name != m_spec.getName())
 		{
 			syncKeySet(); // flush out what currently is in cache
-			m_evaluated_name = evaluated_name;
+			ckdb::elektraKeySetName(*m_spec,
+					evaluated_name.c_str(),
+					ckdb::KDB_O_CASCADING_NAME);
 			syncCache();  // read what we have under new context
 		}
 	}
@@ -614,8 +722,7 @@ private:
 	mutable type m_cache;
 	KeySet & m_ks;
 	Context & m_context;
-	Key m_meta;
-	mutable std::string m_evaluated_name;
+	mutable Key m_spec;
 };
 
 typedef ContextualValue<uint32_t>Integer;
