@@ -14,7 +14,6 @@
  ***************************************************************************/
 
 
-
 /**
  * @defgroup kdb KDB
  * @brief General methods to access the Key database.
@@ -42,7 +41,7 @@
 #include "kdbconfig.h"
 #endif
 
-#if DEBUG && HAVE_STDIO_H
+#if DEBUG && defined(HAVE_STDIO_H)
 #include <stdio.h>
 #endif
 
@@ -790,7 +789,6 @@ int kdbSet(KDB *handle, KeySet *ks, Key *parentKey)
 	Key *initialParent = keyDup(parentKey);
 	Key *errorKey = 0;
 
-
 	if(elektraSplitBuildup(split, handle, parentKey) == -1)
 	{
 		ELEKTRA_SET_ERROR(38, parentKey, "error in elektraSplitBuildup");
