@@ -49,7 +49,7 @@ TEST(MergeResult, ResolveConflictDeletesConflictMeta)
 	Backend b("my_backend", "/");
 	b.addPlugin("resolver");
 	b.addPlugin("dump");
-	b.validated();
+	EXPECT_TRUE(b.validated());
 
 	Key rootKey(Backends::mountpointsPath, KEY_END);
 	KeySet mountConfig;
