@@ -8,6 +8,12 @@ ksNew (50,
 		KEY_VALUE, KDB_DB_HOME, KEY_END),
 	keyNew ("system/elektra/modules/" ELEKTRA_PLUGIN_NAME "/constants/KDB_DB_USER",
 		KEY_VALUE, KDB_DB_USER, KEY_END),
+	keyNew ("system/elektra/modules/" ELEKTRA_PLUGIN_NAME "/constants/ELEKTRA_VARIANT_SYSTEM",
+		KEY_VALUE, ELEKTRA_VARIANT_SYSTEM, KEY_END),
+	keyNew ("system/elektra/modules/" ELEKTRA_PLUGIN_NAME "/constants/ELEKTRA_VARIANT_USER",
+		KEY_VALUE, ELEKTRA_VARIANT_USER, KEY_END),
+	keyNew ("system/elektra/modules/" ELEKTRA_PLUGIN_NAME "/constants/ELEKTRA_VARIANT_BASE",
+		KEY_VALUE, ELEKTRA_VARIANT_BASE, KEY_END),
 	keyNew ("system/elektra/modules/" ELEKTRA_PLUGIN_NAME "/exports", KEY_END),
 	keyNew ("system/elektra/modules/" ELEKTRA_PLUGIN_NAME "/exports/open",
 		KEY_FUNC, ELEKTRA_PLUGIN_FUNCTION(resolver, open),
