@@ -28,12 +28,14 @@
 #ifndef PLUGIN_RESOLVER_H
 #define PLUGIN_RESOLVER_H
 
+#define _GNU_SOURCE // needed for recursive mutex
+
+#include <sys/stat.h>
+
 #include <kdbconfig.h>
 #include <kdbplugin.h>
 #include <kdberrors.h>
 
-#include "lock.h"
-
 #define ERROR_SIZE 1024
 
 typedef struct _resolverHandle resolverHandle;
@@ -41,7 +43,7 @@ typedef struct _resolverHandle resolverHandle;
 struct _resolverHandle
 {
 	int fd;       ///< Descriptor to the locking file
-	time_t mtime; ///< Previous timestamp of the file
+	struct timespec mtime; ///< Previous timestamp of the file
 	mode_t mode;  ///< The mode to set
 
 	char *dirname; ///< directory where real+temp file is
