@@ -13,14 +13,14 @@ void StructChecker::buildup (Factory &, std::string const&)
 void ListChecker::buildup (Factory &f, std::string const& templateParameter)
 {
 	structure = f.get(templateParameter);
-	std::auto_ptr<Checker> c = f.get(templateParameter);
+	CheckerPtr c = f.get(templateParameter);
 	if (!c.get()) throw "Could not create structure of template Parameter";
 
-	// recursive handling code would belong here, but we dont have config
+	// recursive handling code would belong here, but we don't have config
 	// at the moment in ListChecker...
 	c->buildup(f, "");
 
-	structure = c;
+	structure = move(c);
 }
 
 } // end namespace elektra
