@@ -105,20 +105,7 @@ int elektraTypeGet(ckdb::Plugin *, ckdb::KeySet *returned, ckdb::Key *)
 		keyNew ("system/elektra/modules/type/exports/set",
 			KEY_FUNC, elektraTypeSet,
 			KEY_END),
-		keyNew ("system/elektra/modules/type/infos",
-			KEY_VALUE, "All information you want to know", KEY_END),
-		keyNew ("system/elektra/modules/type/infos/author",
-			KEY_VALUE, "Markus Raab <elektra@markus-raab.org>", KEY_END),
-		keyNew ("system/elektra/modules/type/infos/licence",
-			KEY_VALUE, "BSD", KEY_END),
-		keyNew ("system/elektra/modules/type/infos/description",
-			KEY_VALUE, "Copies meta data to keys using typebing", KEY_END),
-		keyNew ("system/elektra/modules/type/infos/provides",
-			KEY_VALUE, "check", KEY_END),
-		keyNew ("system/elektra/modules/type/infos/placements",
-			KEY_VALUE, "presetstorage", KEY_END),
-		keyNew ("system/elektra/modules/type/infos/needs",
-			KEY_VALUE, "", KEY_END),
+#include "readme_type.c"
 		keyNew ("system/elektra/modules/type/infos/version",
 			KEY_VALUE, PLUGINVERSION, KEY_END),
 		KS_END));
