@@ -17,6 +17,26 @@ CheckCommand::CheckCommand()
 
 int CheckCommand::execute(Cmdline const& cl)
 {
+	if (cl.arguments.size() == 0)
+	{
+		Key x;
+		KDB kdb (x);
+		bool wo = x.getMeta<const kdb::Key>("warnings");
+		bool eo = x.getMeta<const kdb::Key>("error");
+		if (wo || eo) std::cerr << "opening of kdb yield following problems:" << std::endl;
+		printWarnings(cerr, x);
+		printError(cerr, x);
+
+		Key y;
+		kdb.close(y);
+		bool wc = y.getMeta<const kdb::Key>("warnings");
+		bool ec = y.getMeta<const kdb::Key>("error");
+		if (wc || ec) std::cerr << "closing of kdb yield following problems:" << std::endl;
+		printWarnings(cerr, y);
+		printError(cerr, y);
+		return  wo + wc*2 + eo * 4 + ec *8;
+	}
+
 	if (cl.arguments.size() != 1)
 	{
 		throw invalid_argument ("One argument required");
@@ -36,14 +56,14 @@ int CheckCommand::execute(Cmdline const& cl)
 	catch (NoPlugin const& p)
 	{
 		cerr << p.what() << endl;
-		return 2;
+		return 1;
 	}
 	catch (PluginCheckException const& p)
 	{
 		cerr << "Plugin did not pass all checks:" << endl;
 		cerr << "See description below:" << endl;
 		cerr << p.what() << endl;
-		return 3;
+		return 2;
 	}
 
 	if (warnings.size() > 0)
@@ -55,6 +75,7 @@ int CheckCommand::execute(Cmdline const& cl)
 		{
 			cerr << "Warning #" << i << ": " << warnings[i] << endl;
 		}
+		return 3;
 	}
 
 	return 0;
