@@ -2,57 +2,6 @@
 
 ssize_t ksCopyInternal(KeySet *ks, size_t to, size_t from);
 
-static KeySet * set_a ()
-{
-	return ksNew(16,
-		keyNew ("user/0", KEY_END),
-		keyNew ("user/a", KEY_END),
-		keyNew ("user/a/a", KEY_END),
-		keyNew ("user/a/a/a", KEY_END),
-		keyNew ("user/a/a/b", KEY_END),
-		keyNew ("user/a/b", KEY_END),
-		keyNew ("user/a/b/a", KEY_END),
-		keyNew ("user/a/b/b", KEY_END),
-		keyNew ("user/a/c", KEY_END),
-		keyNew ("user/a/d", KEY_END),
-		keyNew ("user/a/x/a", KEY_END),
-		keyNew ("user/a/x/b", KEY_END),
-		keyNew ("user/a/x/c", KEY_END),
-		keyNew ("user/a/x/c/a", KEY_END),
-		keyNew ("user/a/x/c/b", KEY_END),
-		keyNew ("user/x", KEY_END),
-		KS_END);
-}
-
-static void test_copy()
-{
-	printf ("Testing operation copy (internal)\n");
-
-	KeySet *copy[17][17];
-#include "data_copy.c"
-
-	KeySet *current;
-
-	for (int i=0; i<17; ++i)
-	{
-		for (int j=0; j<17; ++j)
-		{
-			/* There are some cases which contain duplicates, we have to jump these...*/
-			if (i>j) goto cleanup;
-			if (i==0 && j==16) goto cleanup;
-
-			current = set_a();
-			/* Some blocks are lost in the next operation */
-			succeed_if (ksCopyInternal (current, i, j) != -1, "ksCopyInternal failed");
-			compare_keyset(current, copy[i][j]);
-			ksDel (current);
-
-cleanup:
-			ksDel (copy[i][j]);
-		}
-	}
-}
-
 #define MAX_SIZE 200
 static void test_ksCommonParentName()
 {
@@ -68,21 +17,21 @@ static void test_ksCommonParentName()
 	printf ("Test common parentname\n");
 
 	succeed_if (ksGetCommonParentName(ks, ret, MAX_SIZE) > 0, "could not find correct parentname");
-	succeed_if (strcmp (ret, "system/sw/xorg") == 0, "parentname not correct");
+	succeed_if_same_string (ret, "system/sw/xorg");
 	ksDel (ks);
 
 	ks = ksNew (10,
 		keyNew("system",0),
 		keyNew("user",0),KS_END);
 	succeed_if (ksGetCommonParentName(ks, ret, MAX_SIZE) == 0, "could find correct parentname");
-	succeed_if (strcmp (ret, "") == 0, "parentname not empty");
+	succeed_if_same_string (ret, "");
 	ksDel (ks);
 
 	ks = ksNew (10,
 		keyNew("system/some/thing",0),
 		keyNew("system/other/thing",0), KS_END);
 	succeed_if (ksGetCommonParentName(ks, ret, MAX_SIZE) == 7, "could find correct parentname");
-	succeed_if (strcmp (ret, "system") == 0, "parentname not empty");
+	succeed_if_same_string (ret, "system");
 	ksDel (ks);
 
 	ks = ksNew (10,
@@ -90,7 +39,7 @@ static void test_ksCommonParentName()
 		keyNew("system/here/in/deep/goes/ok/other/thing",0),
 		KS_END);
 	succeed_if (ksGetCommonParentName(ks, ret, MAX_SIZE) > 0, "could find correct parentname");
-	succeed_if (strcmp (ret, "system/here/in/deep/goes/ok") == 0, "parentname not empty");
+	succeed_if_same_string (ret, "system/here/in/deep/goes/ok");
 	ksDel (ks);
 
 	ks = ksNew (10,
@@ -98,13 +47,13 @@ static void test_ksCommonParentName()
 		keyNew("system/here/in/deep/goes/ok/other/thing",0),
 		keyNew("user/unique/thing",0),KS_END);
 	succeed_if (ksGetCommonParentName(ks, ret, MAX_SIZE) == 0, "could find correct parentname");
-	succeed_if (strcmp (ret, "") == 0, "parentname not empty");
+	succeed_if_same_string (ret, "");
 	ksDel (ks);
 
 	ks = ksNew (10,
 		keyNew("user/unique/thing",0),KS_END);
 	succeed_if (ksGetCommonParentName(ks, ret, MAX_SIZE) > 0, "could find correct parentname");
-	succeed_if (strcmp (ret, "user/unique/thing") == 0, "parentname not empty");
+	succeed_if_same_string (ret, "user/unique/thing");
 	ksDel (ks);
 }
 
@@ -154,6 +103,43 @@ static void test_elektraEmptyKeys()
 	ksDel(ks);
 }
 
+static void test_cascadingLookup()
+{
+	printf ("test cascading lookup\n");
+	Key *k0;
+	Key *k1;
+	Key *k2;
+	Key *k3;
+	KeySet *ks = ksNew (10,
+		k0 = keyNew("system/benchmark/override/#0",0),
+		k1 = keyNew("system/benchmark/override/#1",0),
+		k2 = keyNew("user/benchmark/override/#2",0),
+		k3 = keyNew("user/benchmark/override/#3",0),
+		KS_END);
+	Key *search = keyNew ("/benchmark/override/#0",
+		KDB_O_CASCADING_NAME, KEY_END);
+	Key *found = ksLookup(ks, search, 0);
+	succeed_if(found == k0, "found wrong key");
+
+	elektraKeySetName(search, "/benchmark/override/#1",
+		KDB_O_CASCADING_NAME);
+	found = ksLookup(ks, search, 0);
+	succeed_if(found == k1, "found wrong key");
+	keyDel(search);
+
+	search = keyNew ("/benchmark/override/#2",
+		KDB_O_CASCADING_NAME, KEY_END);
+	found = ksLookup(ks, search, 0);
+	succeed_if(found == k2, "found wrong key");
+
+	elektraKeySetName(search, "/benchmark/override/#3",
+		KDB_O_CASCADING_NAME);
+	found = ksLookup(ks, search, 0);
+	succeed_if(found == k3, "found wrong key");
+	keyDel(search);
+	ksDel(ks);
+}
+
 int main()
 {
 	printf("\ntest_ks RESULTS: %d test(s) done. %d error(s).\n", nbTest, nbError);
@@ -161,6 +147,7 @@ int main()
 	test_ksCommonParentName();
 	test_elektraRenameKeys();
 	test_elektraEmptyKeys();
+	test_cascadingLookup();
 
 	return nbError;
 }
